import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated
from pydantic import Field
from typing import Optional
from typing_extensions import Annotated
from unicourt.model.pacer_credential import PacerCredential
from unicourt.model.pacer_credential_list_response import PacerCredentialListResponse
from unicourt.model.pacer_credential_request import PacerCredentialRequest
from unicourt.model.success import Success
from unicourt.api_client import ApiClient, RequestSerialized
from unicourt.api_response import ApiResponse
from unicourt.rest import RESTResponseType
from unicourt.api.pacer_credential_api import PACERCredentialApi
from unicourt.sdk_response import SdkResponse
from unicourt import utils
class PACERCredential:

    @staticmethod
    def add_pacer_credential(
        pacer_credential_request: Optional[PacerCredentialRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[Success]:

        """Add Pacer Credential.

        Register PACER credentials with UniCourt.

        :param pacer_credential_request:
        :type pacer_credential_request: PacerCredentialRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = PACERCredentialApi(api_client).add_pacer_credential_with_http_info(pacer_credential_request = pacer_credential_request, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def add_pacer_credential_with_http_info(
        pacer_credential_request: Optional[PacerCredentialRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Success]:

        """Add Pacer Credential.

        Register PACER credentials with UniCourt.

        :param pacer_credential_request:
        :type pacer_credential_request: PacerCredentialRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            return PACERCredentialApi(api_client).add_pacer_credential_with_http_info(pacer_credential_request = pacer_credential_request, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)

    @staticmethod
    def add_pacer_credential_without_preload_content(
        pacer_credential_request: Optional[PacerCredentialRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[RESTResponseType]:

        """Add Pacer Credential.

        Register PACER credentials with UniCourt.

        :param pacer_credential_request:
        :type pacer_credential_request: PacerCredentialRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = PACERCredentialApi(api_client).add_pacer_credential_without_preload_content_with_http_info(pacer_credential_request = pacer_credential_request, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def get_pacer_credential(
        page_number: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="The page number of the PACER credentials to be retrieved.<br>   - Minimum: 1 ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[PacerCredentialListResponse]:

        """Get Pacer Credential List.

        List registered PACER credentials.

        :param page_number: The page number of the PACER credentials to be retrieved.<br>   - Minimum: 1 
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = PACERCredentialApi(api_client).get_pacer_credential_with_http_info(page_number = page_number, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def get_pacer_credential_with_http_info(
        page_number: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="The page number of the PACER credentials to be retrieved.<br>   - Minimum: 1 ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PacerCredentialListResponse]:

        """Get Pacer Credential List.

        List registered PACER credentials.

        :param page_number: The page number of the PACER credentials to be retrieved.<br>   - Minimum: 1 
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            return PACERCredentialApi(api_client).get_pacer_credential_with_http_info(page_number = page_number, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)

    @staticmethod
    def get_pacer_credential_without_preload_content(
        page_number: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="The page number of the PACER credentials to be retrieved.<br>   - Minimum: 1 ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[RESTResponseType]:

        """Get Pacer Credential List.

        List registered PACER credentials.

        :param page_number: The page number of the PACER credentials to be retrieved.<br>   - Minimum: 1 
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = PACERCredentialApi(api_client).get_pacer_credential_without_preload_content_with_http_info(page_number = page_number, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def get_pacer_credential_by_id(
        pacer_user_id: Annotated[str, Field(min_length=6, strict=True, max_length=40, description="The PACER username for which PACER credentials are to be retrieved.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[PacerCredential]:

        """Get Pacer Credential for a requested pacer User Id.

        Retrieve the PACER credentials for the specified PACER username.

        :param pacer_user_id: The PACER username for which PACER credentials are to be retrieved. (required)
        :type pacer_user_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = PACERCredentialApi(api_client).get_pacer_credential_by_id_with_http_info(pacer_user_id = pacer_user_id, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def get_pacer_credential_by_id_with_http_info(
        pacer_user_id: Annotated[str, Field(min_length=6, strict=True, max_length=40, description="The PACER username for which PACER credentials are to be retrieved.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PacerCredential]:

        """Get Pacer Credential for a requested pacer User Id.

        Retrieve the PACER credentials for the specified PACER username.

        :param pacer_user_id: The PACER username for which PACER credentials are to be retrieved. (required)
        :type pacer_user_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            return PACERCredentialApi(api_client).get_pacer_credential_by_id_with_http_info(pacer_user_id = pacer_user_id, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)

    @staticmethod
    def get_pacer_credential_by_id_without_preload_content(
        pacer_user_id: Annotated[str, Field(min_length=6, strict=True, max_length=40, description="The PACER username for which PACER credentials are to be retrieved.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[RESTResponseType]:

        """Get Pacer Credential for a requested pacer User Id.

        Retrieve the PACER credentials for the specified PACER username.

        :param pacer_user_id: The PACER username for which PACER credentials are to be retrieved. (required)
        :type pacer_user_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = PACERCredentialApi(api_client).get_pacer_credential_by_id_without_preload_content_with_http_info(pacer_user_id = pacer_user_id, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def remove_pacer_credential_by_id(
        pacer_user_id: Annotated[str, Field(min_length=6, strict=True, max_length=40, description="The PACER username for which PACER credentials are to be retrieved.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[Success]:

        """Remove Pacer credential for a specific Pacer User Id.

        De-register the PACER credentials for the specified PACER username.

        :param pacer_user_id: The PACER username for which PACER credentials are to be retrieved. (required)
        :type pacer_user_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = PACERCredentialApi(api_client).remove_pacer_credential_by_id_with_http_info(pacer_user_id = pacer_user_id, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def remove_pacer_credential_by_id_with_http_info(
        pacer_user_id: Annotated[str, Field(min_length=6, strict=True, max_length=40, description="The PACER username for which PACER credentials are to be retrieved.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Success]:

        """Remove Pacer credential for a specific Pacer User Id.

        De-register the PACER credentials for the specified PACER username.

        :param pacer_user_id: The PACER username for which PACER credentials are to be retrieved. (required)
        :type pacer_user_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            return PACERCredentialApi(api_client).remove_pacer_credential_by_id_with_http_info(pacer_user_id = pacer_user_id, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)

    @staticmethod
    def remove_pacer_credential_by_id_without_preload_content(
        pacer_user_id: Annotated[str, Field(min_length=6, strict=True, max_length=40, description="The PACER username for which PACER credentials are to be retrieved.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[RESTResponseType]:

        """Remove Pacer credential for a specific Pacer User Id.

        De-register the PACER credentials for the specified PACER username.

        :param pacer_user_id: The PACER username for which PACER credentials are to be retrieved. (required)
        :type pacer_user_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = PACERCredentialApi(api_client).remove_pacer_credential_by_id_without_preload_content_with_http_info(pacer_user_id = pacer_user_id, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)




from unicourt.sdk.Authentication import Authentication


class TestAuthentication:
    def test_list_all_token_ids():
        return Authentication.list_all_token_ids()

    def test_generate_new_token():
        response = Authentication.generate_new_token()
        Authentication.invalidate_token(token_id=response[0].token_id)
        return response

    def test_invalidate_token():
        response = Authentication.generate_new_token()
        return Authentication.invalidate_token(token_id=response[0].token_id)

    def test_invalidate_all_tokens():
        return Authentication.invalidate_all_tokens()



# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from unicourt.model.preview_document import PreviewDocument
from typing import Optional, Set
from typing_extensions import Self

class CaseDocument(BaseModel):
    """
    CaseDocument
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=12, strict=True, max_length=12)]] = Field(default='CaseDocument', description="Name of the object")
    case_document_id: Optional[Annotated[str, Field(min_length=18, strict=True, max_length=18)]] = Field(default=None, description="UniCourt's Case Document ID.", alias="caseDocumentId")
    sort_order: Optional[StrictInt] = Field(default=None, description="Order of documents how it is being stored in UniCourt.", alias="sortOrder")
    name: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="Document name.")
    description: Optional[StrictStr] = Field(default=None, description="Description of the document.")
    document_filed_date: Optional[Annotated[str, Field(min_length=25, strict=True, max_length=25)]] = Field(default=None, description="Document Date when it was filed. The document date will be either explicitly provided byt the court or if the document is associatated to a docket entry then the document date will be of docket entry date.", alias="documentFiledDate")
    parent_document_id: Optional[Annotated[str, Field(min_length=18, strict=True, max_length=18)]] = Field(default=None, description="Document ID which is the parent document for the current document. This will be null if the current document is a parent document.", alias="parentDocumentId")
    child_document_id_array: Optional[List[Optional[Annotated[str, Field(min_length=18, strict=True, max_length=18)]]]] = Field(default=None, description="List of child document ID's if exists or else it will be an empty lsit.", alias="childDocumentIdArray")
    pages: Optional[StrictInt] = Field(default=None, description="Total number of pages in the document.")
    is_preview_available: Optional[StrictBool] = Field(default=None, description="Determines if a preview is available for the case document.", alias="isPreviewAvailable")
    preview_document: Optional[PreviewDocument] = Field(default=None, alias="previewDocument")
    price: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Price of the document.")
    in_library: Optional[StrictBool] = Field(default=None, description="Determines if the document is present in the UniCourt Library or not.", alias="inLibrary")
    added_to_library_date: Optional[Annotated[str, Field(min_length=25, strict=True, max_length=25)]] = Field(default=None, description="Date and time when the document was downloaded and added to the UniCourt Crowd Source Library.", alias="addedToLibraryDate")
    estimated_order_duration: Optional[Annotated[str, Field(min_length=10, strict=True, max_length=25)]] = Field(default='estimateUnavailable', description="Estimated duration of a Order.", alias="estimatedOrderDuration")
    download_api: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="Link to either view the document if it is downloaded and already present in the UniCourt CrowdSourced Library.", alias="downloadAPI")
    first_fetch_date: Optional[Annotated[str, Field(min_length=25, strict=True, max_length=25)]] = Field(default=None, description="Is the date when the document was first fetched from the court site.", alias="firstFetchDate")
    source_data_status: Optional[StrictStr] = Field(default=None, description="The status of source data of document. If the value of sourceDataStatus is SOURCE_DEPRECATED then it means that the Document has been migrated from old court site to a new court site and the data being shown in the API response is from a old court site. If the sourceDataStatus is NO_LONGER_AVAILABLE_IN_COURT then it means that a particular case is invalid in the court site.", alias="sourceDataStatus")
    __properties: ClassVar[List[str]] = ["object", "caseDocumentId", "sortOrder", "name", "description", "documentFiledDate", "parentDocumentId", "childDocumentIdArray", "pages", "isPreviewAvailable", "previewDocument", "price", "inLibrary", "addedToLibraryDate", "estimatedOrderDuration", "downloadAPI", "firstFetchDate", "sourceDataStatus"]

    @field_validator('estimated_order_duration')
    def estimated_order_duration_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['estimateUnavailable', 'withinMinutes', 'withinHours', 'withinDays', 'withinWeeks']):
            raise ValueError("must be one of enum values ('estimateUnavailable', 'withinMinutes', 'withinHours', 'withinDays', 'withinWeeks')")
        return value

    @field_validator('source_data_status')
    def source_data_status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['NO_LONGER_AVAILABLE_IN_COURT', 'SEALED', 'null']):
            raise ValueError("must be one of enum values ('NO_LONGER_AVAILABLE_IN_COURT', 'SEALED', 'null')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CaseDocument from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of preview_document
        if self.preview_document:
            _dict['previewDocument'] = self.preview_document.to_dict()
        # set to None if sort_order (nullable) is None
        # and model_fields_set contains the field
        if self.sort_order is None and "sort_order" in self.model_fields_set:
            _dict['sortOrder'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if document_filed_date (nullable) is None
        # and model_fields_set contains the field
        if self.document_filed_date is None and "document_filed_date" in self.model_fields_set:
            _dict['documentFiledDate'] = None

        # set to None if parent_document_id (nullable) is None
        # and model_fields_set contains the field
        if self.parent_document_id is None and "parent_document_id" in self.model_fields_set:
            _dict['parentDocumentId'] = None

        # set to None if pages (nullable) is None
        # and model_fields_set contains the field
        if self.pages is None and "pages" in self.model_fields_set:
            _dict['pages'] = None

        # set to None if price (nullable) is None
        # and model_fields_set contains the field
        if self.price is None and "price" in self.model_fields_set:
            _dict['price'] = None

        # set to None if added_to_library_date (nullable) is None
        # and model_fields_set contains the field
        if self.added_to_library_date is None and "added_to_library_date" in self.model_fields_set:
            _dict['addedToLibraryDate'] = None

        # set to None if download_api (nullable) is None
        # and model_fields_set contains the field
        if self.download_api is None and "download_api" in self.model_fields_set:
            _dict['downloadAPI'] = None

        # set to None if source_data_status (nullable) is None
        # and model_fields_set contains the field
        if self.source_data_status is None and "source_data_status" in self.model_fields_set:
            _dict['sourceDataStatus'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CaseDocument from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'CaseDocument',
            "caseDocumentId": obj.get("caseDocumentId"),
            "sortOrder": obj.get("sortOrder"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "documentFiledDate": obj.get("documentFiledDate"),
            "parentDocumentId": obj.get("parentDocumentId"),
            "childDocumentIdArray": obj.get("childDocumentIdArray"),
            "pages": obj.get("pages"),
            "isPreviewAvailable": obj.get("isPreviewAvailable"),
            "previewDocument": PreviewDocument.from_dict(obj["previewDocument"]) if obj.get("previewDocument") is not None else None,
            "price": obj.get("price"),
            "inLibrary": obj.get("inLibrary"),
            "addedToLibraryDate": obj.get("addedToLibraryDate"),
            "estimatedOrderDuration": obj.get("estimatedOrderDuration") if obj.get("estimatedOrderDuration") is not None else 'estimateUnavailable',
            "downloadAPI": obj.get("downloadAPI"),
            "firstFetchDate": obj.get("firstFetchDate"),
            "sourceDataStatus": obj.get("sourceDataStatus")
        })
        return _obj





from unicourt.model.case_update_request import CaseUpdateRequest
from unicourt.sdk.CaseUpdate import CaseUpdate


class TestCaseUpdate:
    def test_update_case():
        return CaseUpdate.update_case(
            case_update_request=CaseUpdateRequest(
                case_id="CASEhq9d8b72d0800c"
            )
        )

    def test_get_case_update_by_case_id():
        return CaseUpdate.get_case_update_by_case_id(
            case_id="CASEhq9d8b72d0800c"
        )

    def test_get_case_updates():
        return CaseUpdate.get_case_updates(
            case_id="CASEak99a698ea5413",
            requested_date='2022-03-08T10:17:56+00:00',
            status="IN_PROGRESS",
            page_number=1,
        )



# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from unicourt.model.possible_norm_law_firm_score_constituents import PossibleNormLawFirmScoreConstituents
from unicourt.model.possible_norm_law_firm_source_details import PossibleNormLawFirmSourceDetails
from typing import Optional, Set
from typing_extensions import Self

class PossibleNormLawFirm(BaseModel):
    """
    PossibleNormLawFirm
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=19, strict=True, max_length=19)]] = Field(default='PossibleNormLawFirm', description="Name of the object")
    norm_law_firm_id: Optional[Annotated[str, Field(min_length=18, strict=True, max_length=18)]] = Field(default=None, alias="normLawFirmId")
    norm_law_firm_name: Optional[Annotated[str, Field(strict=True, max_length=500)]] = Field(default=None, alias="normLawFirmName")
    best_match: Optional[StrictBool] = Field(default=False, alias="bestMatch")
    source_details: Optional[PossibleNormLawFirmSourceDetails] = Field(default=None, alias="sourceDetails")
    confidence_score: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="confidenceScore")
    score_constituents: Optional[PossibleNormLawFirmScoreConstituents] = Field(default=None, alias="scoreConstituents")
    norm_law_firm_api: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, alias="normLawFirmAPI")
    associated_norm_attorney_api: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, alias="associatedNormAttorneyAPI")
    associated_norm_judge_api: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, alias="associatedNormJudgeAPI")
    associated_norm_parties_api: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, alias="associatedNormPartiesAPI")
    case_count_analytics_by_norm_law_firm_api: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, alias="caseCountAnalyticsByNormLawFirmAPI")
    case_count_analytics_by_opposing_norm_law_firm_api: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, alias="caseCountAnalyticsByOpposingNormLawFirmAPI")
    __properties: ClassVar[List[str]] = ["object", "normLawFirmId", "normLawFirmName", "bestMatch", "sourceDetails", "confidenceScore", "scoreConstituents", "normLawFirmAPI", "associatedNormAttorneyAPI", "associatedNormJudgeAPI", "associatedNormPartiesAPI", "caseCountAnalyticsByNormLawFirmAPI", "caseCountAnalyticsByOpposingNormLawFirmAPI"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PossibleNormLawFirm from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of source_details
        if self.source_details:
            _dict['sourceDetails'] = self.source_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of score_constituents
        if self.score_constituents:
            _dict['scoreConstituents'] = self.score_constituents.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PossibleNormLawFirm from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'PossibleNormLawFirm',
            "normLawFirmId": obj.get("normLawFirmId"),
            "normLawFirmName": obj.get("normLawFirmName"),
            "bestMatch": obj.get("bestMatch") if obj.get("bestMatch") is not None else False,
            "sourceDetails": PossibleNormLawFirmSourceDetails.from_dict(obj["sourceDetails"]) if obj.get("sourceDetails") is not None else None,
            "confidenceScore": obj.get("confidenceScore"),
            "scoreConstituents": PossibleNormLawFirmScoreConstituents.from_dict(obj["scoreConstituents"]) if obj.get("scoreConstituents") is not None else None,
            "normLawFirmAPI": obj.get("normLawFirmAPI"),
            "associatedNormAttorneyAPI": obj.get("associatedNormAttorneyAPI"),
            "associatedNormJudgeAPI": obj.get("associatedNormJudgeAPI"),
            "associatedNormPartiesAPI": obj.get("associatedNormPartiesAPI"),
            "caseCountAnalyticsByNormLawFirmAPI": obj.get("caseCountAnalyticsByNormLawFirmAPI"),
            "caseCountAnalyticsByOpposingNormLawFirmAPI": obj.get("caseCountAnalyticsByOpposingNormLawFirmAPI")
        })
        return _obj





from unicourt.api_client import ApiClient
from unicourt.configuration import Configuration
from unicourt.api_response import ApiResponse

from unicourt.exceptions import OpenApiException
from unicourt.exceptions import ApiAttributeError
from unicourt.exceptions import ApiTypeError
from unicourt.exceptions import ApiValueError
from unicourt.exceptions import ApiKeyError
from unicourt.exceptions import ApiException
from unicourt.exceptions import SdkException

from unicourt.sdk.PartyAnalytics import PartyAnalytics
from unicourt.sdk.JudgeAnalytics import JudgeAnalytics
from unicourt.sdk.CaseAnalytics import CaseAnalytics
from unicourt.sdk.CaseUpdate import CaseUpdate
from unicourt.sdk.CaseExport import CaseExport
from unicourt.sdk.CourtAvailability import CourtAvailability
from unicourt.sdk.PACER import PACER
from unicourt.sdk.CaseDocket import CaseDocket
from unicourt.sdk.PACERCredential import PACERCredential
from unicourt.sdk.Callback import Callback
from unicourt.sdk.CaseSearch import CaseSearch
from unicourt.sdk.Authentication import Authentication
from unicourt.sdk.AttorneyAnalytics import AttorneyAnalytics
from unicourt.sdk.CourtStandards import CourtStandards
from unicourt.sdk.CaseTracking import CaseTracking
from unicourt.sdk.CaseDocuments import CaseDocuments
from unicourt.sdk.Usage import Usage
from unicourt.sdk.LawFirmAnalytics import LawFirmAnalytics

from unicourt.model.access_token_id_list_response import AccessTokenIdListResponse
from unicourt.model.access_token_id_response import AccessTokenIdResponse
from unicourt.model.access_token_request import AccessTokenRequest
from unicourt.model.access_token_response import AccessTokenResponse
from unicourt.model.additional_levels import AdditionalLevels
from unicourt.model.address import Address
from unicourt.model.area_of_law import AreaOfLaw
from unicourt.model.area_of_law_response import AreaOfLawResponse
from unicourt.model.associated_norm_attorney import AssociatedNormAttorney
from unicourt.model.associated_norm_attorney_response import AssociatedNormAttorneyResponse
from unicourt.model.associated_norm_judge import AssociatedNormJudge
from unicourt.model.associated_norm_judge_response import AssociatedNormJudgeResponse
from unicourt.model.associated_norm_law_firm import AssociatedNormLawFirm
from unicourt.model.associated_norm_law_firm_response import AssociatedNormLawFirmResponse
from unicourt.model.associated_norm_party import AssociatedNormParty
from unicourt.model.associated_norm_party_response import AssociatedNormPartyResponse
from unicourt.model.associated_so_s_person import AssociatedSoSPerson
from unicourt.model.attorney import Attorney
from unicourt.model.attorney_analytics_api import AttorneyAnalyticsAPI
from unicourt.model.attorney_law_firm import AttorneyLawFirm
from unicourt.model.attorney_representation_type import AttorneyRepresentationType
from unicourt.model.attorney_representation_type_response import AttorneyRepresentationTypeResponse
from unicourt.model.attorney_type import AttorneyType
from unicourt.model.attorney_type_response import AttorneyTypeResponse
from unicourt.model.attorneys import Attorneys
from unicourt.model.bar_record import BarRecord
from unicourt.model.bar_record_preview import BarRecordPreview
from unicourt.model.bar_source_data import BarSourceData
from unicourt.model.bar_source_data_administrative_actions_array_inner import BarSourceDataAdministrativeActionsArrayInner
from unicourt.model.bar_source_data_advanced_degree_array_inner import BarSourceDataAdvancedDegreeArrayInner
from unicourt.model.bar_source_data_bar_status_array_inner import BarSourceDataBarStatusArrayInner
from unicourt.model.bar_source_data_board_certifications_array_inner import BarSourceDataBoardCertificationsArrayInner
from unicourt.model.bar_source_data_committees_array_inner import BarSourceDataCommitteesArrayInner
from unicourt.model.bar_source_data_court_history_array_inner import BarSourceDataCourtHistoryArrayInner
from unicourt.model.bar_source_data_court_of_admissions import BarSourceDataCourtOfAdmissions
from unicourt.model.bar_source_data_disciplinary_history_array_inner import BarSourceDataDisciplinaryHistoryArrayInner
from unicourt.model.bar_source_data_discipline_summaries_array_inner import BarSourceDataDisciplineSummariesArrayInner
from unicourt.model.bar_source_data_employment_history_array_inner import BarSourceDataEmploymentHistoryArrayInner
from unicourt.model.bar_source_data_fees_options_array_inner import BarSourceDataFeesOptionsArrayInner
from unicourt.model.bar_source_data_involvements_array_inner import BarSourceDataInvolvementsArrayInner
from unicourt.model.bar_source_data_law_school_array_inner import BarSourceDataLawSchoolArrayInner
from unicourt.model.bar_source_data_name import BarSourceDataName
from unicourt.model.bar_source_data_open_action_status_array_inner import BarSourceDataOpenActionStatusArrayInner
from unicourt.model.bar_source_data_other_jurisdiction_array_inner import BarSourceDataOtherJurisdictionArrayInner
from unicourt.model.bar_source_data_public_hearing_array_inner import BarSourceDataPublicHearingArrayInner
from unicourt.model.bar_source_data_reason_for_inactivation import BarSourceDataReasonForInactivation
from unicourt.model.bar_source_data_related_cases_array_inner import BarSourceDataRelatedCasesArrayInner
from unicourt.model.bar_source_data_source_info import BarSourceDataSourceInfo
from unicourt.model.bar_source_data_statewide_grievance_committee_history_array_inner import BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner
from unicourt.model.bar_source_data_status_history_array_inner import BarSourceDataStatusHistoryArrayInner
from unicourt.model.bar_source_data_ten_year_discipline_array_inner import BarSourceDataTenYearDisciplineArrayInner
from unicourt.model.billing_cycle_usage_response import BillingCycleUsageResponse
from unicourt.model.billing_cycle_usage_response_api_calls_billable import BillingCycleUsageResponseApiCallsBillable
from unicourt.model.billing_cycle_usage_response_api_calls_credited import BillingCycleUsageResponseApiCallsCredited
from unicourt.model.billing_cycle_usage_response_api_calls_made import BillingCycleUsageResponseApiCallsMade
from unicourt.model.billing_cycle_usage_response_billing_cycle import BillingCycleUsageResponseBillingCycle
from unicourt.model.billing_cycles_response import BillingCyclesResponse
from unicourt.model.callback_list_response import CallbackListResponse
from unicourt.model.callback_list_response_case_document_order_callbacks import CallbackListResponseCaseDocumentOrderCallbacks
from unicourt.model.case import Case
from unicourt.model.case_analytics_api import CaseAnalyticsAPI
from unicourt.model.case_cause_of_action import CaseCauseOfAction
from unicourt.model.case_charge import CaseCharge
from unicourt.model.case_class import CaseClass
from unicourt.model.case_class_coverage import CaseClassCoverage
from unicourt.model.case_class_response import CaseClassResponse
from unicourt.model.case_count_analytics_by_area_of_law import CaseCountAnalyticsByAreaOfLaw
from unicourt.model.case_count_analytics_by_area_of_law_response import CaseCountAnalyticsByAreaOfLawResponse
from unicourt.model.case_count_analytics_by_case_class import CaseCountAnalyticsByCaseClass
from unicourt.model.case_count_analytics_by_case_class_response import CaseCountAnalyticsByCaseClassResponse
from unicourt.model.case_count_analytics_by_case_filed_date import CaseCountAnalyticsByCaseFiledDate
from unicourt.model.case_count_analytics_by_case_filed_date_response import CaseCountAnalyticsByCaseFiledDateResponse
from unicourt.model.case_count_analytics_by_case_type import CaseCountAnalyticsByCaseType
from unicourt.model.case_count_analytics_by_case_type_group import CaseCountAnalyticsByCaseTypeGroup
from unicourt.model.case_count_analytics_by_case_type_group_response import CaseCountAnalyticsByCaseTypeGroupResponse
from unicourt.model.case_count_analytics_by_case_type_response import CaseCountAnalyticsByCaseTypeResponse
from unicourt.model.case_count_analytics_by_court import CaseCountAnalyticsByCourt
from unicourt.model.case_count_analytics_by_court_geo import CaseCountAnalyticsByCourtGeo
from unicourt.model.case_count_analytics_by_court_location import CaseCountAnalyticsByCourtLocation
from unicourt.model.case_count_analytics_by_court_location_response import CaseCountAnalyticsByCourtLocationResponse
from unicourt.model.case_count_analytics_by_court_response import CaseCountAnalyticsByCourtResponse
from unicourt.model.case_count_analytics_by_court_system import CaseCountAnalyticsByCourtSystem
from unicourt.model.case_count_analytics_by_court_system_response import CaseCountAnalyticsByCourtSystemResponse
from unicourt.model.case_count_analytics_by_court_type import CaseCountAnalyticsByCourtType
from unicourt.model.case_count_analytics_by_court_type_response import CaseCountAnalyticsByCourtTypeResponse
from unicourt.model.case_count_analytics_by_jurisdiction_geo import CaseCountAnalyticsByJurisdictionGeo
from unicourt.model.case_count_analytics_by_jurisdiction_geo_response import CaseCountAnalyticsByJurisdictionGeoResponse
from unicourt.model.case_count_analytics_by_norm_attorney import CaseCountAnalyticsByNormAttorney
from unicourt.model.case_count_analytics_by_norm_attorney_response import CaseCountAnalyticsByNormAttorneyResponse
from unicourt.model.case_count_analytics_by_norm_judge import CaseCountAnalyticsByNormJudge
from unicourt.model.case_count_analytics_by_norm_judge_response import CaseCountAnalyticsByNormJudgeResponse
from unicourt.model.case_count_analytics_by_norm_law_firm import CaseCountAnalyticsByNormLawFirm
from unicourt.model.case_count_analytics_by_norm_law_firm_response import CaseCountAnalyticsByNormLawFirmResponse
from unicourt.model.case_count_analytics_by_norm_party import CaseCountAnalyticsByNormParty
from unicourt.model.case_count_analytics_by_norm_party_response import CaseCountAnalyticsByNormPartyResponse
from unicourt.model.case_count_analytics_by_party_role import CaseCountAnalyticsByPartyRole
from unicourt.model.case_count_analytics_by_party_role_group import CaseCountAnalyticsByPartyRoleGroup
from unicourt.model.case_count_analytics_by_party_role_group_response import CaseCountAnalyticsByPartyRoleGroupResponse
from unicourt.model.case_count_analytics_by_party_role_response import CaseCountAnalyticsByPartyRoleResponse
from unicourt.model.case_document import CaseDocument
from unicourt.model.case_document_order_callback import CaseDocumentOrderCallback
from unicourt.model.case_document_order_callback_list_response import CaseDocumentOrderCallbackListResponse
from unicourt.model.case_document_order_pacer_options import CaseDocumentOrderPacerOptions
from unicourt.model.case_document_order_request import CaseDocumentOrderRequest
from unicourt.model.case_documents import CaseDocuments
from unicourt.model.case_export_callback import CaseExportCallback
from unicourt.model.case_export_callback_list_response import CaseExportCallbackListResponse
from unicourt.model.case_relationship_type import CaseRelationshipType
from unicourt.model.case_relationship_type_response import CaseRelationshipTypeResponse
from unicourt.model.case_search_response import CaseSearchResponse
from unicourt.model.case_search_result import CaseSearchResult
from unicourt.model.case_stats import CaseStats
from unicourt.model.case_status import CaseStatus
from unicourt.model.case_status_group import CaseStatusGroup
from unicourt.model.case_status_group_response import CaseStatusGroupResponse
from unicourt.model.case_status_response import CaseStatusResponse
from unicourt.model.case_timeline import CaseTimeline
from unicourt.model.case_track import CaseTrack
from unicourt.model.case_track_list_response import CaseTrackListResponse
from unicourt.model.case_track_preview import CaseTrackPreview
from unicourt.model.case_track_request import CaseTrackRequest
from unicourt.model.case_track_schedule import CaseTrackSchedule
from unicourt.model.case_type import CaseType
from unicourt.model.case_type_group import CaseTypeGroup
from unicourt.model.case_type_group_response import CaseTypeGroupResponse
from unicourt.model.case_type_response import CaseTypeResponse
from unicourt.model.case_update import CaseUpdate
from unicourt.model.case_update_list_response import CaseUpdateListResponse
from unicourt.model.case_update_pacer_options import CaseUpdatePacerOptions
from unicourt.model.case_update_pacer_options_additional_page_array_inner import CaseUpdatePacerOptionsAdditionalPageArrayInner
from unicourt.model.case_update_pacer_options_response import CaseUpdatePacerOptionsResponse
from unicourt.model.case_update_preview import CaseUpdatePreview
from unicourt.model.case_update_request import CaseUpdateRequest
from unicourt.model.cause_of_action import CauseOfAction
from unicourt.model.cause_of_action_additional_data import CauseOfActionAdditionalData
from unicourt.model.cause_of_action_additional_data_response import CauseOfActionAdditionalDataResponse
from unicourt.model.cause_of_action_group import CauseOfActionGroup
from unicourt.model.cause_of_action_group_response import CauseOfActionGroupResponse
from unicourt.model.cause_of_action_response import CauseOfActionResponse
from unicourt.model.charge import Charge
from unicourt.model.charge_additional_data import ChargeAdditionalData
from unicourt.model.charge_additional_data_response import ChargeAdditionalDataResponse
from unicourt.model.charge_degree import ChargeDegree
from unicourt.model.charge_degree_response import ChargeDegreeResponse
from unicourt.model.charge_group import ChargeGroup
from unicourt.model.charge_group_response import ChargeGroupResponse
from unicourt.model.charge_response import ChargeResponse
from unicourt.model.charge_severity import ChargeSeverity
from unicourt.model.charge_severity_response import ChargeSeverityResponse
from unicourt.model.contact import Contact
from unicourt.model.court import Court
from unicourt.model.court_coverage import CourtCoverage
from unicourt.model.court_location import CourtLocation
from unicourt.model.court_location_response import CourtLocationResponse
from unicourt.model.court_response import CourtResponse
from unicourt.model.court_service_status import CourtServiceStatus
from unicourt.model.court_service_status_response import CourtServiceStatusResponse
from unicourt.model.court_system import CourtSystem
from unicourt.model.court_system_response import CourtSystemResponse
from unicourt.model.court_type import CourtType
from unicourt.model.court_type_response import CourtTypeResponse
from unicourt.model.daily_usage_response import DailyUsageResponse
from unicourt.model.docket_entries import DocketEntries
from unicourt.model.docket_entry import DocketEntry
from unicourt.model.docket_entry_primary_documents import DocketEntryPrimaryDocuments
from unicourt.model.docket_entry_secondary_documents import DocketEntrySecondaryDocuments
from unicourt.model.document_download import DocumentDownload
from unicourt.model.email import Email
from unicourt.model.exception import Exception
from unicourt.model.export_file import ExportFile
from unicourt.model.extracted_fields import ExtractedFields
from unicourt.model.hearing import Hearing
from unicourt.model.hearings import Hearings
from unicourt.model.individual import Individual
from unicourt.model.invalidate_access_token_request import InvalidateAccessTokenRequest
from unicourt.model.judge import Judge
from unicourt.model.judge_analytics_api import JudgeAnalyticsAPI
from unicourt.model.judge_type import JudgeType
from unicourt.model.judge_type_response import JudgeTypeResponse
from unicourt.model.judges import Judges
from unicourt.model.jurisdiction_geo import JurisdictionGeo
from unicourt.model.jurisdiction_geo_response import JurisdictionGeoResponse
from unicourt.model.last_tracked_details import LastTrackedDetails
from unicourt.model.law_firm_analytics_api import LawFirmAnalyticsAPI
from unicourt.model.matched_object import MatchedObject
from unicourt.model.nature_of_suit import NatureOfSuit
from unicourt.model.norm_attorney import NormAttorney
from unicourt.model.norm_attorney_search_response import NormAttorneySearchResponse
from unicourt.model.norm_attorney_search_result import NormAttorneySearchResult
from unicourt.model.norm_corporate_group import NormCorporateGroup
from unicourt.model.norm_judge import NormJudge
from unicourt.model.norm_judge_public_data import NormJudgePublicData
from unicourt.model.norm_judge_public_data_aba_ratings import NormJudgePublicDataAbaRatings
from unicourt.model.norm_judge_public_data_bio import NormJudgePublicDataBio
from unicourt.model.norm_judge_public_data_education_array_inner import NormJudgePublicDataEducationArrayInner
from unicourt.model.norm_judge_public_data_judicial_source import NormJudgePublicDataJudicialSource
from unicourt.model.norm_judge_public_data_name_history_array_inner import NormJudgePublicDataNameHistoryArrayInner
from unicourt.model.norm_judge_search_response import NormJudgeSearchResponse
from unicourt.model.norm_judge_search_result import NormJudgeSearchResult
from unicourt.model.norm_law_firm import NormLawFirm
from unicourt.model.norm_law_firm_search_response import NormLawFirmSearchResponse
from unicourt.model.norm_law_firm_search_result import NormLawFirmSearchResult
from unicourt.model.norm_organization import NormOrganization
from unicourt.model.norm_organization_ticker_array_inner import NormOrganizationTickerArrayInner
from unicourt.model.norm_party import NormParty
from unicourt.model.norm_party_search_response import NormPartySearchResponse
from unicourt.model.norm_party_search_result import NormPartySearchResult
from unicourt.model.pacer_case_search_content import PACERCaseSearchContent
from unicourt.model.pacer_case_search_results import PACERCaseSearchResults
from unicourt.model.pacer_import_case import PACERImportCase
from unicourt.model.pacer_import_case_results import PACERImportCaseResults
from unicourt.model.pacer_party_search_content import PACERPartySearchContent
from unicourt.model.pacer_party_search_results import PACERPartySearchResults
from unicourt.model.pacer_search_page_info import PACERSearchPageInfo
from unicourt.model.pacer_search_receipt import PACERSearchReceipt
from unicourt.model.pcl_case import PCLCase
from unicourt.model.pcl_party import PCLParty
from unicourt.model.pacer_credential import PacerCredential
from unicourt.model.pacer_credential_list_response import PacerCredentialListResponse
from unicourt.model.pacer_credential_request import PacerCredentialRequest
from unicourt.model.parties import Parties
from unicourt.model.party import Party
from unicourt.model.party_analytics_api import PartyAnalyticsAPI
from unicourt.model.party_attorney_association import PartyAttorneyAssociation
from unicourt.model.party_attorney_associations import PartyAttorneyAssociations
from unicourt.model.party_role import PartyRole
from unicourt.model.party_role_group import PartyRoleGroup
from unicourt.model.party_role_group_response import PartyRoleGroupResponse
from unicourt.model.party_role_response import PartyRoleResponse
from unicourt.model.phone import Phone
from unicourt.model.possible_norm_attorney import PossibleNormAttorney
from unicourt.model.possible_norm_attorney_score_constituents import PossibleNormAttorneyScoreConstituents
from unicourt.model.possible_norm_judge import PossibleNormJudge
from unicourt.model.possible_norm_judge_score_constituents import PossibleNormJudgeScoreConstituents
from unicourt.model.possible_norm_law_firm import PossibleNormLawFirm
from unicourt.model.possible_norm_law_firm_score_constituents import PossibleNormLawFirmScoreConstituents
from unicourt.model.possible_norm_law_firm_source_details import PossibleNormLawFirmSourceDetails
from unicourt.model.possible_norm_party import PossibleNormParty
from unicourt.model.possible_norm_party_score_constituents import PossibleNormPartyScoreConstituents
from unicourt.model.preview_document import PreviewDocument
from unicourt.model.raw_ordered_data import RawOrderedData
from unicourt.model.raw_ordered_data_child import RawOrderedDataChild
from unicourt.model.raw_ordered_data_child_child_array_inner import RawOrderedDataChildChildArrayInner
from unicourt.model.referenced_docket_number import ReferencedDocketNumber
from unicourt.model.related_case import RelatedCase
from unicourt.model.related_cases import RelatedCases
from unicourt.model.related_norm_party import RelatedNormParty
from unicourt.model.sos_associated_norm_organization import SOSAssociatedNormOrganization
from unicourt.model.sos_data import SOSData
from unicourt.model.sos_data_preview import SOSDataPreview
from unicourt.model.sos_name_change import SOSNameChange
from unicourt.model.schedule import Schedule
from unicourt.model.service_history import ServiceHistory
from unicourt.model.service_status import ServiceStatus
from unicourt.model.service_status_down_details import ServiceStatusDownDetails
from unicourt.model.similar_norm_attorney import SimilarNormAttorney
from unicourt.model.source_case_data import SourceCaseData
from unicourt.model.source_cause_of_action import SourceCauseOfAction
from unicourt.model.source_charge import SourceCharge
from unicourt.model.source_charge_additional_data import SourceChargeAdditionalData
from unicourt.model.source_page_data import SourcePageData
from unicourt.model.source_structured_data import SourceStructuredData
from unicourt.model.success import Success


ACCESS_TOKEN = ""
TOKEN_ID = ""
CLIENT_ID = ""
CLIENT_SECRET = ""
api_client = None
configuration = None



# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class PACERSearchReceipt(BaseModel):
    """
    PACERSearchReceipt
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=18, strict=True, max_length=18)]] = Field(default='PACERSearchReceipt', description="Name of the object")
    transaction_date: Optional[datetime] = Field(default=None, description="Date when the transaction was made at the pacer court site.", alias="transactionDate")
    search_fee: Optional[Annotated[str, Field(min_length=3, strict=True, max_length=5)]] = Field(default=None, description="PACER Search Fee.", alias="searchFee")
    billable_pages: Optional[StrictInt] = Field(default=None, description="No of pages that was billed for the given PACER search.", alias="billablePages")
    login_id: Optional[Annotated[str, Field(strict=True, max_length=40)]] = Field(default=None, description="ID which is used for PACER login.", alias="loginId")
    client_code: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="client code added if any was set.", alias="clientCode")
    firm_id: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="Firm ID.", alias="firmId")
    search: Optional[Annotated[str, Field(strict=True, max_length=1000000)]] = Field(default=None, description="Details of the search made for this request.")
    description: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="Description of the search made.")
    cso_id: Optional[Annotated[int, Field(strict=True)]] = Field(default=None, description="PACER Account ID.", alias="csoId")
    report_id: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="Report ID for the search made.", alias="reportId")
    __properties: ClassVar[List[str]] = ["object", "transactionDate", "searchFee", "billablePages", "loginId", "clientCode", "firmId", "search", "description", "csoId", "reportId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PACERSearchReceipt from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if client_code (nullable) is None
        # and model_fields_set contains the field
        if self.client_code is None and "client_code" in self.model_fields_set:
            _dict['clientCode'] = None

        # set to None if firm_id (nullable) is None
        # and model_fields_set contains the field
        if self.firm_id is None and "firm_id" in self.model_fields_set:
            _dict['firmId'] = None

        # set to None if search (nullable) is None
        # and model_fields_set contains the field
        if self.search is None and "search" in self.model_fields_set:
            _dict['search'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if cso_id (nullable) is None
        # and model_fields_set contains the field
        if self.cso_id is None and "cso_id" in self.model_fields_set:
            _dict['csoId'] = None

        # set to None if report_id (nullable) is None
        # and model_fields_set contains the field
        if self.report_id is None and "report_id" in self.model_fields_set:
            _dict['reportId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PACERSearchReceipt from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'PACERSearchReceipt',
            "transactionDate": obj.get("transactionDate"),
            "searchFee": obj.get("searchFee"),
            "billablePages": obj.get("billablePages"),
            "loginId": obj.get("loginId"),
            "clientCode": obj.get("clientCode"),
            "firmId": obj.get("firmId"),
            "search": obj.get("search"),
            "description": obj.get("description"),
            "csoId": obj.get("csoId"),
            "reportId": obj.get("reportId")
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.case import Case
from unicourt.model.case_update_pacer_options_response import CaseUpdatePacerOptionsResponse
from unicourt.model.last_tracked_details import LastTrackedDetails
from unicourt.model.schedule import Schedule
from typing import Optional, Set
from typing_extensions import Self

class CaseTrack(BaseModel):
    """
    CaseTrack
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=9, strict=True, max_length=9)]] = Field(default='CaseTrack', description="Name of the object.")
    case_id: Optional[Annotated[str, Field(min_length=18, strict=True, max_length=18)]] = Field(default=None, description="Unique Id for a Case in UniCourt.", alias="caseId")
    pacer_options: Optional[CaseUpdatePacerOptionsResponse] = Field(default=None, alias="pacerOptions")
    schedule: Optional[Schedule] = None
    last_tracked_details: Optional[LastTrackedDetails] = Field(default=None, alias="lastTrackedDetails")
    last_fetch_date: Optional[datetime] = Field(default=None, description="The date and time when the case was last fetched from the Court. This date and time is in UTC. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz, Note: It is not necessary that every time the case is fetched from Court we find changes in the case information. It could be that we already have the latest information from the Court and no changes exist.", alias="lastFetchDate")
    last_fetch_date_with_updates: Optional[datetime] = Field(default=None, description="The date and time when the case was last fetched from the Court where we found changes in the case information. This date and time is in UTC. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz,", alias="lastFetchDateWithUpdates")
    case_api: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=255)]] = Field(default=None, alias="caseAPI")
    case: Optional[Case] = None
    __properties: ClassVar[List[str]] = ["object", "caseId", "pacerOptions", "schedule", "lastTrackedDetails", "lastFetchDate", "lastFetchDateWithUpdates", "caseAPI", "case"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CaseTrack from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of pacer_options
        if self.pacer_options:
            _dict['pacerOptions'] = self.pacer_options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of schedule
        if self.schedule:
            _dict['schedule'] = self.schedule.to_dict()
        # override the default output from pydantic by calling `to_dict()` of last_tracked_details
        if self.last_tracked_details:
            _dict['lastTrackedDetails'] = self.last_tracked_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of case
        if self.case:
            _dict['case'] = self.case.to_dict()
        # set to None if last_fetch_date (nullable) is None
        # and model_fields_set contains the field
        if self.last_fetch_date is None and "last_fetch_date" in self.model_fields_set:
            _dict['lastFetchDate'] = None

        # set to None if last_fetch_date_with_updates (nullable) is None
        # and model_fields_set contains the field
        if self.last_fetch_date_with_updates is None and "last_fetch_date_with_updates" in self.model_fields_set:
            _dict['lastFetchDateWithUpdates'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CaseTrack from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'CaseTrack',
            "caseId": obj.get("caseId"),
            "pacerOptions": CaseUpdatePacerOptionsResponse.from_dict(obj["pacerOptions"]) if obj.get("pacerOptions") is not None else None,
            "schedule": Schedule.from_dict(obj["schedule"]) if obj.get("schedule") is not None else None,
            "lastTrackedDetails": LastTrackedDetails.from_dict(obj["lastTrackedDetails"]) if obj.get("lastTrackedDetails") is not None else None,
            "lastFetchDate": obj.get("lastFetchDate"),
            "lastFetchDateWithUpdates": obj.get("lastFetchDateWithUpdates"),
            "caseAPI": obj.get("caseAPI"),
            "case": Case.from_dict(obj["case"]) if obj.get("case") is not None else None
        })
        return _obj


